==> mongo_drf_endpoint_logger-0.0.1.tar.gz: mongo_drf_endpoint_logger-0.0.1/setup.py <==
# MIT License
#
# Copyright (c) 2022 M. Inan Delibas
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

import setuptools


def get_description():
    with open("README.md", "r") as fh:
        long_description = fh.read()
    return long_description


setuptools.setup(
    name="mongo_drf_endpoint_logger",
    version="0.0.1",
    author="M. Inan Delibas",
    author_email="inanndelibas@gmail.com",
    description="An API Logger for your Django Rest Framework project with Mongo DB.",
    long_description=get_description(),
    long_description_content_type="text/markdown",
    url="https://github.com/inanpy/mongo_drf_endpoint_logger",
    packages=setuptools.find_packages(),
    install_requires=["djangorestframework>=3.7.4"],
    license='MIT',
    python_requires='>=3.6',
    include_package_data=True,
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)

==> mongo_drf_endpoint_logger-0.0.2.tar.gz: mongo_drf_endpoint_logger-0.0.2/setup.py <==
# MIT License
#
# Copyright (c) 2022 M. Inan Delibas
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

import setuptools


def get_description():
    with open("README.md", "r") as fh:
        long_description = fh.read()
    return long_description


setuptools.setup(
    name="mongo_drf_endpoint_logger",
    version="0.0.2",
    author="Inan Delibas",
    author_email="inanndelibas@gmail.com",
    description="An API Logger for your Django Rest Framework project with Mongo DB.",
    long_description=get_description(),
    long_description_content_type="text/markdown",
    url="https://github.com/inanpy/mongo_drf_endpoint_logger",
    packages=setuptools.find_packages(),
    install_requires=[
        "Django>=3.2.14"
        "djangorestframework>=3.13.1"
        "mongoengine>=0.24.1"
    ],
    license='MIT',
    python_requires='>=3.6',
    include_package_data=True,
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
